import React, { useEffect, useState } from 'react';
import { View, Text, StyleSheet, TouchableOpacity, Image, StatusBar, Linking, Platform, PermissionsAndroid } from 'react-native';
import { MapView, Marker, MapType } from 'react-native-amap3d';
import Geolocation from '@react-native-community/geolocation';
import { rpx } from '../../utils/rpx';
import { useNavigation } from '@react-navigation/native';
import { transformFromWGSToGCJ } from '../../utils/coordtransform';

const DeviceMap = () => {
  const navigation = useNavigation();
  const [location, setLocation] = useState({
    latitude: 26.95500669,
    longitude: 120.32736769,
  });
  const [isLoading, setIsLoading] = useState(false);

  // 请求 Android 定位权限
  const requestAndroidPermission = async () => {
    try {
      const granted = await PermissionsAndroid.request(
        PermissionsAndroid.PERMISSIONS.ACCESS_FINE_LOCATION,
        {
          title: "位置信息权限",
          message: "需要获取您的位置信息",
          buttonNeutral: "稍后询问",
          buttonNegative: "取消",
          buttonPositive: "确定"
        }
      );
      return granted === PermissionsAndroid.RESULTS.GRANTED;
    } catch (err) {
      console.warn(err);
      return false;
    }
  };

  const getCurrentLocation = async () => {
    setIsLoading(true);
    try {
      // ... 权限检查和配置代码保持不变

      // 同时发起高精度和低精度定位请求
      const highAccuracyPromise = new Promise((resolve, reject) => {
        Geolocation.getCurrentPosition(
          resolve,
          reject,
          { 
            enableHighAccuracy: true, 
            timeout: 5000,
            maximumAge: 1000
          }
        );
      });

      const lowAccuracyPromise = new Promise((resolve, reject) => {
        Geolocation.getCurrentPosition(
          resolve,
          reject,
          { 
            enableHighAccuracy: false, 
            timeout: 10000,
            maximumAge: 5000
          }
        );
      });

      Promise.race([highAccuracyPromise, lowAccuracyPromise])
        .then((position: any) => {
          console.log('原始定位结果:', position);
          // 转换坐标系
          const gcjLocation = transformFromWGSToGCJ(
            position.coords.latitude,
            position.coords.longitude
          );
          console.log('转换后的坐标:', gcjLocation);
          setLocation(gcjLocation);
          setIsLoading(false);
        })
        .catch((error) => {
          console.error('定位失败:', error);
          setIsLoading(false);
        });

    } catch (error) {
      console.error('获取位置信息失败:', error);
      setIsLoading(false);
    }
  };

  // 位置监听也需要转换坐标系
  useEffect(() => {
    getCurrentLocation();

    const watchId = Geolocation.watchPosition(
      (position) => {
        const gcjLocation = transformFromWGSToGCJ(
          position.coords.latitude,
          position.coords.longitude
        );
        setLocation(gcjLocation);
      },
      (error) => {
        console.error('位置监听错误:', error);
      },
      {
        enableHighAccuracy: true,
        timeout: 5000,
        maximumAge: 1000,
        distanceFilter: 10
      }
    );

    return () => {
      Geolocation.clearWatch(watchId);
    };
  }, []);

  // 跳转到高德地图
  const openAMap = async () => {
    const url = Platform.select({
      android: `androidamap://navi?sourceApplication=appname&lat=${location.latitude}&lon=${location.longitude}&dev=0&style=2`,
      ios: `iosamap://navi?sourceApplication=appname&lat=${location.latitude}&lon=${location.longitude}&dev=0&style=2`,
    });
    const imageUrl = "https://lxnapi.ccttiot.com/bike/img/static/uRx1B8B8acbquF2TO7Ry";
    const fallbackUrl = `https://uri.amap.com/navigation?to=${location.longitude},${location.latitude},目的地&mode=car&coordinate=gaode`;

    try {
      // 检查是否安装了高德地图
      const supported = await Linking.canOpenURL(url);
      
      if (supported) {
        await Linking.openURL(url);
      } else {
        // 如果没有安装高德地图，则打开网页版
        await Linking.openURL(fallbackUrl);
      }
    } catch (error) {
      console.error('无法打开高德地图:', error);
      // 打开网页版作为后备方案
      await Linking.openURL(fallbackUrl);
    }
  };

  return (
    <View style={styles.container}>
      <MapView
        style={styles.map}
        mapType={MapType.Standard}
        zoomControlsEnabled={false}
        scrollEnabled={true}
        zoomEnabled={true}
        initialCameraPosition={{
          target: {
            latitude: location.latitude,
            longitude: location.longitude,
          },
          zoom: 15,
        }}
      >
       
        <Marker
          position={{
            latitude: location.latitude,
            longitude: location.longitude,
          }}
          icon={{ uri: 'imageUrl' }}
        />
      </MapView>
      <Image source={{ uri: 'https://api.ccttiot.com/smartmeter/img/static/uOCaLkinKXhZLxCkTFAQ' }} style={styles.locationIcon} />
      <View style={styles.bottomCard}>
        <View style={styles.addressInfo}>
          <Text style={styles.addressText}>
            福建省宁德市福鼎市海滨路200号靠近福鼎第四中学
          </Text>
          <Image 
            source={{ uri: 'https://api.ccttiot.com/smartmeter/img/static/ucBlLZW1SpAaKxSQYkr6' }}
            style={styles.voiceIcon}
          />
        </View>
        <View style={styles.timeBlock}>
          <Image source={{ uri: 'https://api.ccttiot.com/smartmeter/img/static/uMnpK2e8az06pzJrKms5' }} style={styles.timeClock} />
          <Text style={styles.timeText1}>
            12:00
          </Text>
        </View>
        <TouchableOpacity 
          style={styles.navigationButton}
          onPress={openAMap}
        >
          <Text style={styles.buttonText}>导航到车辆</Text>
        </TouchableOpacity>
      </View>
    </View>
  );
};

const styles = StyleSheet.create({

  container: {
    flex: 1,
    backgroundColor: '#FFFFFF',
  },
  locationIcon: {
    position: 'absolute',
    right: rpx(32),
    bottom: rpx(400),
    width: rpx(90),
    height: rpx(90),
  },
  map: {
    flex: 1,
    width: '100%',
  },
  timeBlock: {
    display: 'flex',
    flexDirection: 'row', // 确保内容水平排列
    alignSelf: 'flex-start',
    justifyContent:'center',
    alignItems:'center',
    padding: rpx(8) ,
    paddingHorizontal:rpx(18),
    backgroundColor: '#EFEFEF',
    borderRadius: rpx(29),
    flexWrap: 'nowrap', // 防止换行
    marginBottom:rpx(40),
  },
  
  timeClock:{
    marginRight:rpx(14),
    width:rpx(26),
    height:rpx(26),
  },
  timeText1:{
    fontSize:rpx(24),
    color:'#808080',

  },
  header: {
    position: 'absolute',
    top: 0,
    left: 0,
    right: 0,
    height: rpx(88),
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
    paddingHorizontal: rpx(32),
    backgroundColor: 'transparent',
  },
  backButton: {
    width: rpx(44),
    height: rpx(44),
    justifyContent: 'center',
    alignItems: 'center',
  },
  backIcon: {
    width: rpx(32),
    height: rpx(32),
  },
  timeContainer: {
    flex: 1,
    alignItems: 'center',
  },
  timeText: {
    fontSize: rpx(28),
    color: '#333333',
  },
  menuButton: {
    width: rpx(44),
    height: rpx(44),
    justifyContent: 'center',
    alignItems: 'center',
  },
  menuIcon: {
    width: rpx(32),
    height: rpx(32),
  },
  bottomCard: {
    position: 'absolute',
    bottom: 0,
    left: 0,
    right: 0,
    backgroundColor: '#FFFFFF',
    borderTopLeftRadius: rpx(24),
    borderTopRightRadius: rpx(24),
    padding: rpx(36),
  },
  addressInfo: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: rpx(32),
  },
  addressText: {
    flex: 1,
    fontSize: rpx(36),
    color: '#333333',
    marginRight: rpx(16),
  },
  voiceIcon: {
    width: rpx(90),
    height: rpx(90),
  },
  navigationButton: {
    height: rpx(96),
    backgroundColor: '#2089FF',
    borderRadius: rpx(20),
    justifyContent: 'center',
    alignItems: 'center',
  },
  buttonText: {
    fontSize: rpx(32),
    color: '#FFFFFF',
    fontWeight: '500',
  },
});

export default DeviceMap;